<?php

class Dina_Elementor_Widgets {

	protected static $instance = null;

	public static function get_instance() {
		if ( ! isset( static::$instance ) ) {
			static::$instance = new static;
		}

		return static::$instance;
	}

	protected function __construct() {
		
		//Include WooCommerce Widgets
		if ( class_exists( 'WooCommerce' ) ) {
			require_once('el-widgets/products.php');
			require_once('el-widgets/products-grid.php');
			require_once('el-widgets/timed-products.php');
			require_once('el-widgets/special-offer.php');
			require_once('el-widgets/offer.php');
			require_once('el-widgets/daily-discount.php');
			require_once('el-widgets/category-slider.php');
			require_once('el-widgets/category-grid.php');
			require_once('el-widgets/viewed-products.php');
			if ( dina_opt( 'product_brand' ) ) {
				require_once('el-widgets/brand-slider.php');
				require_once('el-widgets/brand-grid.php');
			}
		}

		//Include Site Widgets
		require_once('el-widgets/services.php');
		require_once('el-widgets/posts.php');
		require_once('el-widgets/posts-grid.php');
		require_once('el-widgets/ads-image.php');
		require_once('el-widgets/logo-slider.php');
		require_once('el-widgets/slider.php');
		require_once('el-widgets/daily-slider.php');
		require_once('el-widgets/text-box.php');
		require_once('el-widgets/dina-site-info.php');
		require_once('el-widgets/dina-ticker.php');
		require_once('el-widgets/dina-social-links.php');

		//Include Header Widgets
		if ( dina_active_elpro() ) {
			require_once('el-widgets/header-widgets/dina-header-logo.php');
			require_once('el-widgets/header-widgets/dina-search-bar.php');
			require_once('el-widgets/header-widgets/dina-user-btns.php');
			require_once('el-widgets/header-widgets/dina-mobile-user-btns.php');
			require_once('el-widgets/header-widgets/dina-mobile-menu-btn.php');
			require_once('el-widgets/header-widgets/dina-shopping-cart.php');
			require_once('el-widgets/header-widgets/dina-whishlist-btn.php');
			require_once('el-widgets/header-widgets/dina-compare-btn.php');
			require_once('el-widgets/header-widgets/dina-dark-mode-toggle.php');
		}
		
		add_action( 'elementor/widgets/register', [ $this, 'dina_register_widgets' ] );
	}

	public function dina_register_widgets() {
		
		//Call WooCommerce Widgets
		if ( class_exists( 'WooCommerce' ) ) {
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Woo_Products() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Woo_Products_Grid() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Timed_Products() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Special_Offer() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Dialy_Discount() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Woo_Offer() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Category_Slider() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Category_Grid() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Recently_Viewed_Products() );
			if( dina_opt( 'product_brand' ) ) {
				\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Brands_Slider() );
				\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Brands_Grid() );
			}
		}

		//Call Site Widgets
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Our_Service_Box() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Blog_Posts() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Blog_Posts_Grid() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Ads_Image() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Logo_Slider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Slider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Daily_Slider() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Text_Box() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Site_Info() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Text_Ticker() );
		\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Social_Links() );

		//Call Header Widgets
		if ( dina_active_elpro() ) {
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Header_Logo() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Search_Bar() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_User_Buttons() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Mobile_User_Buttons() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Mobile_Menu_Btn() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Shopping_Cart() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Wishlist_Btn() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Compare_Btn() );
			\Elementor\Plugin::instance()->widgets_manager->register( new \Elementor\Dina_Dark_Mode_Toggle() );
		}
		
	}

}

add_action( 'init', 'dina_elementor_init' );
function dina_elementor_init() {
	Dina_Elementor_Widgets::get_instance();
}

function dina_add_elementor_widget_categories( $elements_manager ) {

	$elements_manager->add_category(
		'dina-kala',
		[
			'title' => __( 'DinaKala', 'dina-kala' ),
			'icon' => 'fa fa-plug',
		]
	);

	if ( dina_active_elpro() ) {
		$elements_manager->add_category(
			'dina-kala-header',
			[
				'title' => __( 'DinaKala header widgets', 'dina-kala' ),
				'icon' => 'fa fa-plug',
			]
		);
	}
}
add_action( 'elementor/elements/categories_registered', 'dina_add_elementor_widget_categories' );

//Disable Elementor Google Fonts
add_filter( 'elementor/frontend/print_google_fonts', '__return_false' );

//Register Elementor Location's
add_action( 'elementor/theme/register_locations', 'dina_register_elementor_locations' );
function dina_register_elementor_locations( $elementor_theme_manager ) {

	$elementor_theme_manager->register_location( 'header' );
	$elementor_theme_manager->register_location( 'footer' );
	// $elementor_theme_manager->register_location( 'single' );
	// $elementor_theme_manager->register_location( 'archive' );

}

//Register elementor preview mode script
add_action( 'elementor/preview/enqueue_scripts', 'dina_elementor_script' );
function dina_elementor_script() {
    wp_enqueue_script('dina-js-elementor', DI_URI . '/js/elementor.js', array('jquery'), DI_VER, true);
}

//Register Elementor Panel styles
add_action('elementor/editor/before_enqueue_scripts', function() {
    wp_register_style('el-style', DI_URI . '/css/elementor.css', array() , DI_VER);
    wp_enqueue_style('el-style');
    wp_register_style('dina-awe', DI_URI . '/css/fontawesome.min.css', array() , DI_VER);
    wp_enqueue_style('dina-awe');
});

//Disable elementor use mini cart template
function dina_disable_elementor_use_mini_cart_template(){
	update_option( 'elementor_use_mini_cart_template', 'no' );
}
add_action( 'init', 'dina_disable_elementor_use_mini_cart_template' );