<?php
/*
Theme Designed By: Meysam Hosseinkhani
Email: Meysam98@Gmail.com
Demo Website: Dinakala.I-design.ir
Author Website: i-design.ir
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Checkout billing phone validation (Checking length)
//add_action( 'woocommerce_checkout_process', 'dina_checkout_field_process' );
function dina_checkout_field_process() {
    if ( $_POST['billing_phone'] && strlen( $_POST['billing_phone'] ) < 10 )
        wc_add_notice( __( 'Please type a correct phone number', 'dina-kala' ), 'error' );
}

// Add name and lastname fields to registration form.
add_action( 'woocommerce_register_form_start', 'dina_woo_reg_form_fields_start' );
function dina_woo_reg_form_fields_start() {
    if ( ! dina_opt( 'reg_field_fname_lname' ) ) 
        return;
    ?>
    <p class="form-row form-row-first">
        <label for="billing_first_name"><?php echo dina_opt( 'reg_field_fname_label' ); ?>
            <?php if ( dina_opt( 'reg_req_fname_lname' ) ) { ?>
                <span class="required">*</span>
            <?php } ?>
        </label>
        <input type="text" class="woocommerce-Input woocommerce-Input--text input-text" type="text" class="input-text" name="billing_first_name" id="billing_first_name" value="<?php if ( !empty( $_POST['billing_first_name'] ) ) esc_attr_e( $_POST['billing_first_name'] ); ?>" autocomplete="given-name" />
    </p>
    <p class="form-row form-row-last">
        <label for="billing_last_name"><?php echo dina_opt( 'reg_field_lname_label' ); ?>
            <?php if ( dina_opt( 'reg_req_fname_lname' ) ) { ?>
                <span class="required">*</span>
            <?php } ?>
        <input type="text" class="woocommerce-Input woocommerce-Input--text input-text" type="text" class="input-text" name="billing_last_name" id="billing_last_name" value="<?php if ( !empty( $_POST['billing_last_name'] ) ) esc_attr_e( $_POST['billing_last_name'] ); ?>" autocomplete="family-name" />
    </p>
    <?php
}

// Add phone field to registration form.
add_action( 'woocommerce_register_form', 'dina_woo_reg_form_fields_end' );
function dina_woo_reg_form_fields_end() {
    if ( ! dina_opt( 'reg_field_phone' ) ) 
        return;
    ?>
    <p class="form-row form-row-wide">
        <label for="reg_billing_phone"><?php echo dina_opt( 'reg_field_phone_label' ); ?>
            <?php if ( dina_opt( 'reg_req_phone' ) ) { ?>
                <span class="required">*</span>
            <?php } ?>
        </label>
        <input type="tel" class="woocommerce-Input woocommerce-Input--text input-text" name="billing_phone" id="reg_billing_phone" value="<?php if ( !empty( $_POST['billing_phone'] ) ) esc_attr_e( $_POST['billing_phone'] ); ?>" autocomplete="tel" />
    </p>
    <div class="clear"></div>
    <?php
}

// Checking & validation of custom fields in registration form.
add_action( 'woocommerce_register_post', 'dina_woo_validate_reg_form_fields', 10, 3 );
function dina_woo_validate_reg_form_fields( $username, $email, $validation_errors ) {

    if ( dina_opt( 'reg_field_fname_lname' ) ) {
        //First name field
        if ( isset( $_POST['billing_first_name'] ) && empty( $_POST['billing_first_name'] ) && dina_opt( 'reg_req_fname_lname' ) ) {
            $validation_errors->add( 'billing_first_name_error', __( 'Please enter a valid first name.', 'dina-kala' ) );
        }
        //Last name field
        if ( isset( $_POST['billing_last_name'] ) && empty( $_POST['billing_last_name'] ) && dina_opt( 'reg_req_fname_lname' ) ) {
            $validation_errors->add( 'billing_last_name_error', __( 'Please enter a valid last name.', 'dina-kala' ) );
        }
    }

    //Phone field
    if ( dina_opt( 'reg_field_phone' ) ) {
        if ( isset( $_POST['billing_phone'] ) && empty( $_POST['billing_phone'] ) && dina_opt( 'reg_req_phone' ) ) {
            $validation_errors->add( 'billing_phone_error', __( 'Please enter a valid phone number.', 'dina-kala' ) );
        }
        //Phone field (10 character minimal)
        if ( isset( $_POST['billing_phone'] ) && ! empty( $_POST['billing_phone'] ) && strlen( $_POST['billing_phone'] ) < 11 ) {
            $validation_errors->add( 'billing_phone_error', __( 'Please enter a valid phone number.', 'dina-kala' ) );
        }
    }
    
    return $validation_errors;
}

// Save custom fields to DB.
add_action( 'woocommerce_created_customer', 'dina_save_extra_register_fields' );
function dina_save_extra_register_fields($customer_id) {

    $nickname = '';

    //First name field
    if ( dina_opt( 'reg_field_fname_lname' ) && isset( $_POST['billing_first_name'] ) ) {
        $nickname .= sanitize_text_field( $_POST['billing_first_name'] );
        update_user_meta( $customer_id, 'first_name', sanitize_text_field( $_POST['billing_first_name'] ) );
        update_user_meta( $customer_id, 'billing_first_name', sanitize_text_field( $_POST['billing_first_name'] ) );
    }

    //Last name field
    if (  dina_opt( 'reg_field_fname_lname' ) && isset( $_POST['billing_last_name'] ) ) {
        $nickname .= ' ' . sanitize_text_field( $_POST['billing_last_name'] );
        update_user_meta( $customer_id, 'last_name', sanitize_text_field( $_POST['billing_last_name'] ) );
        update_user_meta( $customer_id, 'billing_last_name', sanitize_text_field( $_POST['billing_last_name'] ) );
    }

    //Display name
    if (  dina_opt( 'reg_field_fname_lname' ) && ! empty( $nickname ) ) {  
        wp_update_user( array( 'ID' => $customer_id, 'display_name' => sanitize_text_field( $nickname ) , 'nickname' => sanitize_text_field( $nickname )  ) );
    }

    //Phone field
    if (  dina_opt( 'reg_field_phone' ) && isset( $_POST['billing_phone'] ) ) {
        update_user_meta( $customer_id, 'phone', sanitize_text_field( $_POST['billing_phone'] ) );
        update_user_meta( $customer_id, 'billing_phone', sanitize_text_field( $_POST['billing_phone'] ) );
    }
}